/********************************************************************************
** Form generated from reading UI file 'sitesettingshtml5item.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SITESETTINGSHTML5ITEM_H
#define UI_SITESETTINGSHTML5ITEM_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_SiteSettingsHtml5Item
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpacerItem *horizontalSpacer;
    QComboBox *defaultPermissionCombo;
    QPushButton *browseButton;

    void setupUi(QWidget *SiteSettingsHtml5Item)
    {
        if (SiteSettingsHtml5Item->objectName().isEmpty())
            SiteSettingsHtml5Item->setObjectName("SiteSettingsHtml5Item");
        SiteSettingsHtml5Item->resize(556, 61);
        verticalLayout = new QVBoxLayout(SiteSettingsHtml5Item);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(SiteSettingsHtml5Item);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        defaultPermissionCombo = new QComboBox(SiteSettingsHtml5Item);
        defaultPermissionCombo->setObjectName("defaultPermissionCombo");

        horizontalLayout->addWidget(defaultPermissionCombo);

        browseButton = new QPushButton(SiteSettingsHtml5Item);
        browseButton->setObjectName("browseButton");

        horizontalLayout->addWidget(browseButton);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(SiteSettingsHtml5Item);

        QMetaObject::connectSlotsByName(SiteSettingsHtml5Item);
    } // setupUi

    void retranslateUi(QWidget *SiteSettingsHtml5Item)
    {
        label->setText(QString());
        browseButton->setText(QCoreApplication::translate("SiteSettingsHtml5Item", "Browse", nullptr));
        (void)SiteSettingsHtml5Item;
    } // retranslateUi

};

namespace Ui {
    class SiteSettingsHtml5Item: public Ui_SiteSettingsHtml5Item {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SITESETTINGSHTML5ITEM_H
